@@ -554,3 +554,52 @@ func TestOnFinishAlreadyFinished(t *testing.T) {
 		t.Fatal("Timeout waiting for OnFinish to fire")
 	}
 }
+
+func TestOnFinishDataRace(t *testing.T) {
+	jobID.Store(0)
+	job, _, err := NewJob(context.Background(), ctxFn, rc.Params{"_async": true})
+	assert.NoError(t, err)
+	var expect, got uint64
+	finished := make(chan struct{})
+	stop, stopped := make(chan struct{}), make(chan struct{})
+	go func() {
+	Loop:
+		for {
+			select {
+			case <-stop:
+				break Loop
+			default:
+				_, err := OnFinish(job.ID, func() {
+					finished <- struct{}{}
+				})
+				assert.NoError(t, err)
+				expect += 1
+			}
+		}
+		close(stopped)
+	}()
+
+	time.Sleep(10 * time.Millisecond)
+	job.Stop()
+
+	// Wait for the first OnFinish to fire
+	<-finished
+	got += 1
+
+	// Stop the OnFinish producer
+	close(stop)
+	<-stopped
+
+	timeout := time.After(5 * time.Second)
+	for {
+		if got == expect {
+			break
+		}
+		select {
+		case <-finished:
+			got += 1
+		case <-timeout:
+			t.Fatal("Timeout waiting for all OnFinish calls to fire")
+		}
+	}
+}
